@@ -17,6 +17,9 @@ from pathlib import Path
 from pyutmodel.PyutField import PyutField
 from pyutmodel.PyutField import PyutFields
 from pyutmodel.PyutLink import PyutLink
+from pyutmodel.PyutLinkedObject import PyutLinkedObject
+from pyutmodel.PyutNote import PyutNote
+from pyutmodel.PyutText import PyutText
 from pyutmodel.PyutType import PyutType
 from pyutmodel.PyutClass import PyutClass
 from pyutmodel.PyutMethod import PyutMethod
@@ -24,7 +27,10 @@ from pyutmodel.PyutParameter import PyutParameter
 from pyutmodel.PyutStereotype import PyutStereotype
 from pyutmodel.PyutVisibilityEnum import PyutVisibilityEnum
 
+from ogl.OglNote import OglNote
+from ogl.OglText import OglText
 from ogl.OglLink import OglLink
+from ogl.OglNoteLink import OglNoteLink
 from ogl.OglClass import OglClass
 from ogl.OglInterface2 import OglInterface2
 from ogl.OglAggregation import OglAggregation
@@ -88,6 +94,12 @@ class MermaidWriter:
                     oglClass:  OglClass  = cast(OglClass, oglObject)
                     generatedString: str = self._generateClassStanza(oglClass)
                     mermaidString += f'{generatedString}'
+                case OglNote():
+                    pass
+                case OglText():
+                    oglText: OglText = cast(OglText, oglObject)
+                    generatedString = self._mermaidStandaloneNoteStanza(oglText)
+                    mermaidString += f'{generatedString}'
                 case OglLink():
                     pass
                 case _:
@@ -97,6 +109,15 @@ class MermaidWriter:
         with self._fqFileName.open(mode='a') as fd:
             fd.write(f'{mermaidString}')
 
+    def _mermaidStandaloneNoteStanza(self, oglText: OglText) -> str:
+
+        pyutText: PyutText = oglText.pyutObject
+        generatedString: str = (
+            f'{indent1}note "{pyutText.content}"{eol}'
+        )
+
+        return generatedString
+
     def _generateClassStanza(self, oglObject: OglClass) -> str:
         """
 
@@ -152,50 +173,20 @@ class MermaidWriter:
                 case OglInterface():
                     oglInterface: OglInterface = cast(OglInterface, oglObject)
                     linkRefrain = self._getRealizationLinkRefrain(oglInterface)
+                case OglNoteLink():
+                    oglNoteLink: OglNoteLink = cast(OglNoteLink, oglObject)
+                    linkRefrain = self._getNoteLinkRefrain(oglNoteLink)
                 case OglAssociation():      # Most general needs to be last
                     oglAssociation: OglAssociation = cast(OglAssociation, oglObject)
                     linkRefrain = self._getAssociationLinkRefrain(oglAssociation=oglAssociation, arrowType=MermaidArrow.ASSOCIATION_LINK)
                 case OglInterface2():
-                    pass
+                    self.logger.warning(f'OglInterface2 (lollipops) not supported in Mermaid')
                 case _:
                     pass        # Ignore non links
             linksStanza += linkRefrain
 
         return linksStanza
 
-    def _getAssociationLinkRefrain(self, oglAssociation: OglAssociation, arrowType: MermaidArrow) -> str:
-        """
-        For Composition and Aggregation the diamond is on the source side
-        Produces refrains of the form:
-
-        For composition:
-        Person "1" *-- "1" Heart
-
-        Where Person is the 'composer' and Heart is the 'composed'
-
-        For aggregation
-
-        Author "1.*" o-- "0.*" Book
-
-        Where Author aggregates Books
-
-        Args:
-            oglAssociation:
-            arrowType:
-
-        Returns:
-        """
-        pyutLink: PyutLink = oglAssociation.pyutObject
-        sourceName:      str = pyutLink.getSource().name
-        destinationName: str = pyutLink.getDestination().name
-        self.logger.info(f'{oglAssociation} {sourceName=} {destinationName=}')
-
-        sourceCardinality, destinationCardinality = self._getCardinalityStrings(pyutLink)
-        linkRefrain = (
-            f'{indent1}{sourceName} {sourceCardinality} {arrowType.value} {destinationCardinality} {destinationName} : {pyutLink.name}{eol}'
-        )
-        return linkRefrain
-
     def _getInheritanceLinkRefrain(self, oglLink: OglLink) -> str:
         """
         Produces strings of the form:
@@ -231,6 +222,55 @@ class MermaidWriter:
 
         return linkRefrain
 
+    def _getAssociationLinkRefrain(self, oglAssociation: OglAssociation, arrowType: MermaidArrow) -> str:
+        """
+        For Composition and Aggregation the diamond is on the source side
+        Produces refrains of the form:
+
+        For composition:
+        Person "1" *-- "1" Heart
+
+        Where Person is the 'composer' and Heart is the 'composed'
+
+        For aggregation
+
+        Author "1.*" o-- "0.*" Book
+
+        Where Author aggregates Books
+
+        Args:
+            oglAssociation:
+            arrowType:
+
+        Returns:
+        """
+        pyutLink: PyutLink = oglAssociation.pyutObject
+        sourceName:      str = pyutLink.getSource().name
+        destinationName: str = pyutLink.getDestination().name
+        self.logger.info(f'{oglAssociation} {sourceName=} {destinationName=}')
+
+        sourceCardinality, destinationCardinality = self._getCardinalityStrings(pyutLink)
+        linkRefrain: str = (
+            f'{indent1}{sourceName} {sourceCardinality} {arrowType.value} {destinationCardinality} {destinationName} : {pyutLink.name}{eol}'
+        )
+        return linkRefrain
+
+    def _getNoteLinkRefrain(self, oglNoteLink: OglNoteLink) -> str:
+        """
+
+        Args:
+            oglNoteLink: The note link
+
+        Returns:  Mermaid string for a note link
+        """
+        pyutLink:  PyutLink          = oglNoteLink.pyutObject
+        destObject: PyutLinkedObject = pyutLink.getDestination()
+        pyutNote:   PyutNote         = pyutLink.getSource()
+        linkRefrain: str = (
+            f'{indent1}note for {destObject.name} "{pyutNote.content}"{eol}'
+        )
+        return linkRefrain
+
     def _getCardinalityStrings(self, pyutLink) -> Tuple[str, str]:
         """
 
